@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-09-15'; # DATE
-our $VERSION = '1.57'; # VERSION
+our $DATE = '2015-09-18'; # DATE
+our $VERSION = '1.58'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -179,14 +179,13 @@ sub BUILD {
                 $_t->('format'),
                 schema => ['str*' => in => $formats],
             };
-            # XXX support --naked-res
             $copts->{json} = {
                 $_t->('json'),
                 summary => N__("Equivalent to --format=json-pretty"),
-                handler => sub {
-                    my ($go, $val, $r) = @_;
-                    $r->{format} = 'json-pretty';
-                },
+            };
+            $copts->{naked_res} = {
+                $_t->('naked_res'),
+                summary => N__("When outputing as JSON, strip result envelope"),
             };
             $copts->{format_options} = {
                 getopt  => "format-options=s",
@@ -786,7 +785,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.57 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-09-15.
+This document describes version 1.58 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-09-18.
 
 =head1 SYNOPSIS
 
